What is generated is commonly referred to as the :term:`workspace`. The workspace can live anywhere on the filesystem. The default is the current directory. The workspace can also be passed into the ``linchpin`` command line with the ``--workspace (--w)`` option, or it can be set with the ``$WORKSPACE`` environmental variable. 

An functional workspace can be found in :dirs1.5:`the source code <workspace>`.

.. FIXME: Update PinFiles. Provide expanded examples in both YAML and JSON.


